# Generated by roxygen2: do not edit by hand

S3method(plot,getgamma1bin)
S3method(plot,getgamma1cont)
S3method(plot,getgamma2bin)
S3method(plot,getgamma2cont)
S3method(plot,pbayesdecisionprob1bin)
S3method(plot,pbayesdecisionprob1cont)
S3method(plot,pbayesdecisionprob2bin)
S3method(plot,pbayesdecisionprob2cont)
S3method(print,pbayesdecisionprob1bin)
S3method(print,pbayesdecisionprob1cont)
S3method(print,pbayesdecisionprob2bin)
S3method(print,pbayesdecisionprob2cont)
export(allmultinom)
export(getgamma1bin)
export(getgamma1cont)
export(getgamma2bin)
export(getgamma2cont)
export(getjointbin)
export(pbayesdecisionprob1bin)
export(pbayesdecisionprob1cont)
export(pbayesdecisionprob2bin)
export(pbayesdecisionprob2cont)
export(pbayespostpred1bin)
export(pbayespostpred1cont)
export(pbayespostpred2bin)
export(pbayespostpred2cont)
export(pbetabinomdiff)
export(pbetadiff)
export(ptdiff_MC)
export(ptdiff_MM)
export(ptdiff_NI)
export(rdirichlet)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_colorsteps)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_color_gradient)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_color_stepsn)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_fill_stepsn)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,unit)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rgb)
importFrom(gridExtra,grid.arrange)
importFrom(mvtnorm,pmvt)
importFrom(stats,dbeta)
importFrom(stats,dbinom)
importFrom(stats,dmultinom)
importFrom(stats,dt)
importFrom(stats,integrate)
importFrom(stats,pbeta)
importFrom(stats,pt)
importFrom(stats,rbinom)
importFrom(stats,rchisq)
importFrom(stats,rgamma)
importFrom(stats,rmultinom)
importFrom(stats,rnorm)
importFrom(stats,rt)
importFrom(stats,setNames)
